import { IconChild, IconPredecessor, IconRSForm } from '@/components/Icons';
import LinkTopic from '@/components/ui/LinkTopic';
import { HelpTopic } from '@/models/miscellaneous';

function HelpThesaurus() {
  return (
    <div className='text-justify'>
      <h1>Тезаурус</h1>
      <p>
        Данные раздел содержит основные термины и определения, используемые в работе с Порталом. Термины сгруппированы
        по ключевым сущностям. Более подробно описание отношений между терминами даются в отдельных разделах данной
        Справки через гиперссылки. Также указываются графические обозначения (иконки, цвета), используемые для
        обозначения соответствующих сущностей в интерфейсе Портала.
      </p>
      <h2>Концептуализация</h2>
      <p>Раздел в разработке...</p>
      <h2>Концептуальная схема</h2>
      <p>
        <IconRSForm size='1rem' className='inline-icon' />{' '}
        <LinkTopic text='Концептуальная схема' topic={HelpTopic.CC_SYSTEM} /> (<i>система определений, КС</i>) –
        совокупность отдельных понятий и утверждений, а также связей между ними, задаваемых определениями.
      </p>
      <p>
        Экспликация КС – изложение (процесс и результат) концептуальной схемы с помощью заданного языка описания –
        набора формальных конструкций и правил построения определений.
      </p>
      <p>
        Родоструктурная экспликация КС – экспликация КС с помощью{' '}
        <LinkTopic text='аппарата родов структур' topic={HelpTopic.RSLANG} />.
      </p>

      <h2>Конституента</h2>
      <p>
        Конституента – это выделенная часть КС, являющаяся отдельным понятием, схемой построения понятия, либо
        утверждением, связывающим введенные понятия.{' '}
        <LinkTopic text='Аттрибутами конституенты' topic={HelpTopic.CC_CONSTITUENTA} /> в родоструктурной экспликации
        являются Термин, Конвенция, Типизация (Структура), Формальное определение, Текстовое определение, Комментарий.
      </p>
      <ul>
        По <b>наличию формального определения в рамках КС</b> выделены:
        <li>
          базовое понятие (<i>неопределяемое понятие</i>) не имеет определения и задано конвенцией и аксиомами;
        </li>
        <li>
          производное понятие (<i>выводимое понятие</i>) имеет определение.
        </li>
      </ul>

      <br />

      <ul>
        Для описания <b>тесно связанных понятий</b> введены следующие термины:
        <li>
          порождающее выражение – формальное определение, основанное на одной внешней конституенте и использующее только
          формальное разворачивание (не вводит нового предметного содержания);
        </li>
        <li>основа данного понятия – понятие, на котором основано порождающее выражение данной конституенты;</li>
        <li>
          порожденное понятие данным понятием – понятие, определение которого является порождающим выражением,
          основанным на данном понятии.
        </li>
      </ul>

      <br />

      <ul>
        Для описания <b>отождествления</b> введены:
        <li>отождествляемые конституенты – конституенты, состоящие в отождествлении;</li>
        <li>удаляемая конституента – конституента, удаляемая в ходе отождествления;</li>
        <li>
          замещающая конституента – конституента, обозначение которой замещает обозначение удаляемой конституенты в
          формальных выражениях иных конституент в ходе отождествления;
        </li>
      </ul>

      <br />

      <ul>
        Для описания <b>наследования</b> конституент в рамках ОСС введены:
        <li>
          <IconChild size='1rem' className='inline-icon' /> наследованная конституента – конституента, перенесенная из
          другой КС в рамках операции синтеза;
        </li>
        <li>собственная конституента – конституента, не являющаяся наследником других конституент;</li>
        <li>
          <IconPredecessor size='1rem' className='inline-icon' /> исходная конституента для данной конституенты –
          собственная конституента, прямым или опосредованным наследником которой является данная конституента.
        </li>
      </ul>

      <br />

      <ul>
        По <b>назначению</b> выделены:
        <li>
          базисное множество (X1) задает неопределяемое понятие, представленное структурой множества, чьи элементы
          различимы и не сравнимы с элементами других базисных множеств;
        </li>
        <li>
          константное множество (C1) задает неопределяемое понятие, моделируемое термом теории множеств, который
          поддерживает ряд формальных операций над его элементами;
        </li>
        <li>
          родовая структура (S1) задает неопределяемое понятие, имеющее определенную структуру, построенную на базисных
          множествах и константных множеств. Содержание родовой структуры формируется{' '}
          <LinkTopic text='отношением типизации' topic={HelpTopic.RSL_TYPES} />, аксиомами и конвенцией;
        </li>
      </ul>

      <h2>Операционная схема синтеза</h2>
      <p>Раздел в разработке...</p>

      <h2>Операция</h2>
      <p>Раздел в разработке...</p>
    </div>
  );
}

export default HelpThesaurus;
